@@ -103,7 +103,7 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
                     logging.info("outputs[" + str(idx) + "] : " +
                                  str(output))
                     print(CYAN, "outputs[", str(idx), "]: ", NC)
-                    # Crop long output to terminal
+                    # Crop long output (e.g. images) to terminal
                     print_cropped_output(output)
 
                 print(BLUE, "-".center(80, "-"), NC)
@@ -113,8 +113,7 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
                     message = "outputs are the same"
 
                 else:
-                    # Some differences can be ignored - look closer for
-                    # those
+                    # Some differences can be ignored - look closer for those
                     comparison_pass = examine_output_diff(
                         ignore_output_differences, outputs[0], outputs[1],
                         debug
@@ -140,6 +139,8 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
 
 
 def check_for_errors(comparison_errors):
+
+    comparison_result = False
     error_message = ""
     error_content = ""
 
@@ -156,18 +157,15 @@ def check_for_errors(comparison_errors):
     return comparison_result, error_message, error_content
 
 
-def print_comparison_results(
-    notebook_filenames, comparison_result, error_message, error_content, debug
-):
+def print_comparison_results(notebook_filenames, comparison_result,
+                             error_message, error_content, debug):
 
     # Print & log errors
     if error_message != "":
         print("\n", RED, error_message, "\n", error_content)
         logging.error(error_message)
         logging.error(error_content)
-
     print(GREEN) if comparison_result else print(RED)
-
     print("-".center(80, "-"))
     print(" comparison result: " + str(comparison_result))
     print("-".center(80, "-"), NC)
@@ -372,6 +370,8 @@ def examine_output_key_data(key, nb0, nb1, debug):
 
 def examine_output_key_text(key, nb0, nb1, debug):
 
+    debug and print("Entered examine_output_key_text()")
+
     comparison_pass = True
     found_key_to_ignore = False
 
@@ -419,13 +419,14 @@ def examine_output_key_text(key, nb0, nb1, debug):
                 found_key_to_ignore = True
         comparison_pass = found_key_to_ignore
 
-    # Check for the occaisional \r
-    if "\r" in nb0[key] or "\r" in nb1[key]:
-        if nb0[key].replace("\r", "") == nb1[key].replace("\r", ""):
+    # Check for the occaissional extra \r or \n
+    if "\r" in nb0[key] or "\r" in nb1[key] or \
+            "\n" in nb0[key] or "\n" in nb1[key]:
+        if nb0[key].replace("\r", "") == nb1[key].replace("\r", "") or \
+                nb0[key].replace("\n", "") == nb1[key].replace("\n", ""):
             comparison_pass = True
 
     if debug:
-        print("Entered examine_output_key_text()")
         print("      key: ", key)
         print("      values: ")
         print("         nb0[", key, "]: ", nb0[key])
